==> lxqt-config_1.3.0.orig.tar.xz: lxqt-config-1.3.0/lxqt-config-monitor/translations/lxqt-config-monitor_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Gyors lehetőségek</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Kiterjesztett nézet</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Egyesített nézet</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶     Csak az első</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Csak a második</translation>
    </message>
</context>
<context>
    <name>LoadSettings</name>
    <message>
        <location filename="../loadsettings.cpp" line="98"/>
        <source>Default monitor settings has been applied. If you want change monitors settings, please, use lxqt-config-monitor.</source>
        <translation>Az alapértelmezett monitorbeállítások lettek alkalmazva. Ha módosítani szeretné a monitorok beállításait, használja az lxqt-config-monitor alkalmazást.</translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Monitor beállítások</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Mentett beállítások</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="38"/>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="45"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="52"/>
        <source>Apply</source>
        <translation>Alkalmaz</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="62"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="65"/>
        <source>Left</source>
        <translation>Balra</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="68"/>
        <source>Inverted</source>
        <translation>Inverz</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="71"/>
        <source>Right</source>
        <translation>Jobbra</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <location filename="../managesavedsettings.cpp" line="76"/>
        <source>True</source>
        <translation>Igaz</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <location filename="../managesavedsettings.cpp" line="76"/>
        <source>False</source>
        <translation>Hamis</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="136"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="136"/>
        <source>Name:</source>
        <translation>Név:</translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <location filename="../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Monitorok csatlakozva tartása</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Monitor beállítások</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="70"/>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="106"/>
        <source>Fast Menu</source>
        <translation>Gyors menü</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="110"/>
        <source>Set position</source>
        <translation>Pozicionálás</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="229"/>
        <source>Advanced settings</source>
        <translation>Haladó beállítások</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Beállítás</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="29"/>
        <source> (x)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="45"/>
        <source> (y)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="78"/>
        <source>Resolution:</source>
        <translation>Felbontás:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="90"/>
        <source>Enable this display</source>
        <translation>Engedélyezés</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="98"/>
        <source>This is my primary display</source>
        <translation>Ez az elsődleges kijelző</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="103"/>
        <source>This screen extends another display</source>
        <translation>Kiterjesztés más kijelzőre is</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Haladó</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="146"/>
        <source>Refresh rate:</source>
        <translation>Frissítési gyakoriság:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="153"/>
        <source>Rotation:</source>
        <translation>Forgatás:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Információ</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Kijelző információ</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="129"/>
        <source>Name: %1
</source>
        <translation>Név: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="130"/>
        <source>Vendor: %1
</source>
        <translation>Forgalmazó: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="131"/>
        <source>Serial: %1
</source>
        <translation>Sorozatszám: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="132"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Képméret: %1cm x %2cm
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="133"/>
        <source>Serial number: %1
</source>
        <translation>Sorozatszám: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="134"/>
        <source>EISA device ID: %1
</source>
        <translation>EISA eszköz ID: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="154"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="155"/>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="156"/>
        <source>Right</source>
        <translation>Jobbra</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="157"/>
        <source>Inverted</source>
        <translation>Megfordítva</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="245"/>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Mentett beállítások kezelése</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name:</source>
        <translation>Név:</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>A beállítások megváltoztak</translation>
    </message>
    <message>
        <location filename="../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Megfelelőek a jelenlegi beállítások?</translation>
    </message>
    <message numerus="yes">
        <location filename="../timeoutdialog.cpp" line="63"/>
        <source>%n second(s) remaining</source>
        <translatorcomment>%n másodperc van hátra</translatorcomment>
        <translation>
            <numerusform>%n másodperc van hátra</numerusform>
        </translation>
    </message>
</context>
</TS>

==> lxqt-config-2.2.0.tar.xz: lxqt-config-2.2.0/lxqt-config-monitor/translations/lxqt-config-monitor_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>FastMenu</name>
    <message>
        <location filename="../fastmenu.ui" line="20"/>
        <source>Fast options</source>
        <translation>Gyors lehetőségek</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="40"/>
        <source> ❶ ❷ Extended view</source>
        <translation> ❶ ❷ Kiterjesztett nézet</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="45"/>
        <source> ❶ ❶ Unified view</source>
        <translation> ❶ ❶ Egyesített nézet</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="50"/>
        <source> ❶     Only first</source>
        <translation> ❶     Csak az első</translation>
    </message>
    <message>
        <location filename="../fastmenu.ui" line="55"/>
        <source>     ❷ Only second</source>
        <translation>     ❷ Csak a második</translation>
    </message>
</context>
<context>
    <name>LoadSettings</name>
    <message>
        <location filename="../loadsettings.cpp" line="97"/>
        <source>Default monitor settings applied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../loadsettings.cpp" line="98"/>
        <source>Adjust your screens with LXQt Monitor Settings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../loadsettings.cpp" line="107"/>
        <source>lxqt-config-monitor: Settings applied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../loadsettings.cpp" line="109"/>
        <source>lxqt-config-monitor: Settings not applied.
If this is a Wayland compositor, you could try kanshi to configure your monitor(s).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageSavedSettings</name>
    <message>
        <location filename="../managesavedsettings.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Monitor beállítások</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="27"/>
        <source>Saved settings</source>
        <translation>Mentett beállítások</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="45"/>
        <source>Rename</source>
        <translation>Átnevezés</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.ui" line="52"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="66"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="69"/>
        <source>Left</source>
        <translation>Balra</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="72"/>
        <source>Inverted</source>
        <translation>Inverz</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="75"/>
        <source>Right</source>
        <translation>Jobbra</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="79"/>
        <location filename="../managesavedsettings.cpp" line="80"/>
        <source>True</source>
        <translation>Igaz</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="79"/>
        <location filename="../managesavedsettings.cpp" line="80"/>
        <source>False</source>
        <translation>Hamis</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="139"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="139"/>
        <source>Name:</source>
        <translation>Név:</translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="172"/>
        <source>Settings Activation Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../managesavedsettings.cpp" line="173"/>
        <source>Selected settings cannot be applied with currently active monitors.

Please choose from the highlighted configurations.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MonitorPictureDialog</name>
    <message>
        <location filename="../monitorpicture.ui" line="27"/>
        <source>Keep monitors attached</source>
        <translation>Monitorok csatlakozva tartása</translation>
    </message>
</context>
<context>
    <name>MonitorSettingsDialog</name>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="14"/>
        <source>Monitor Settings</source>
        <translation>Monitor beállítások</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.ui" line="70"/>
        <source>Settings</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="62"/>
        <source>Platform Unsupported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="63"/>
        <source>LXQt monitor settings are currently unsupported under this wayland compositor.

You can configure your monitor(s) with kanshi.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="118"/>
        <source>Fast Menu</source>
        <translation>Gyors menü</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="122"/>
        <source>Set position</source>
        <translation>Pozicionálás</translation>
    </message>
    <message>
        <location filename="../monitorsettingsdialog.cpp" line="241"/>
        <source>Advanced settings</source>
        <translation>Haladó beállítások</translation>
    </message>
</context>
<context>
    <name>MonitorWidget</name>
    <message>
        <location filename="../monitorwidget.ui" line="21"/>
        <source>Setup</source>
        <translation>Beállítás</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="64"/>
        <source> (x)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="80"/>
        <source> (y)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="36"/>
        <source>Resolution:</source>
        <translation>Felbontás:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="27"/>
        <source>Enable this display</source>
        <translation>Engedélyezés</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="49"/>
        <source>This is my primary display</source>
        <translation>Ez az elsődleges kijelző</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="54"/>
        <source>This screen extends another display</source>
        <translation>Kiterjesztés más kijelzőre is</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="125"/>
        <source>Advanced</source>
        <translation>Haladó</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="143"/>
        <source>Refresh rate:</source>
        <translation>Frissítési gyakoriság:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="133"/>
        <source>Rotation:</source>
        <translation>Forgatás:</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="176"/>
        <source>Info</source>
        <translation>Információ</translation>
    </message>
    <message>
        <location filename="../monitorwidget.ui" line="182"/>
        <source>Display information</source>
        <translation>Kijelző információ</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="129"/>
        <source>Name: %1
</source>
        <translation>Név: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="130"/>
        <source>Vendor: %1
</source>
        <translation>Forgalmazó: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="131"/>
        <source>Serial: %1
</source>
        <translation>Sorozatszám: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="132"/>
        <source>Display size: %1cm x %2cm
</source>
        <translation>Képméret: %1cm x %2cm
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="133"/>
        <source>Serial number: %1
</source>
        <translation>Sorozatszám: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="134"/>
        <source>EISA device ID: %1
</source>
        <translation>EISA eszköz ID: %1
</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="155"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="156"/>
        <source>Left</source>
        <translation>Bal</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="157"/>
        <source>Right</source>
        <translation>Jobbra</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="158"/>
        <source>Inverted</source>
        <translation>Megfordítva</translation>
    </message>
    <message>
        <location filename="../monitorwidget.cpp" line="248"/>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Manage Saved Settings</source>
        <translation>Mentett beállítások kezelése</translation>
    </message>
</context>
<context>
    <name>SaveSettings</name>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../savesettings.cpp" line="87"/>
        <source>Name:</source>
        <translation>Név:</translation>
    </message>
</context>
<context>
    <name>TimeoutDialog</name>
    <message>
        <location filename="../timeoutdialog.ui" line="14"/>
        <source>Settings are changed</source>
        <translation>A beállítások megváltoztak</translation>
    </message>
    <message>
        <location filename="../timeoutdialog.ui" line="46"/>
        <source>Are the current settings OK for you?</source>
        <translation>Megfelelőek a jelenlegi beállítások?</translation>
    </message>
    <message numerus="yes">
        <location filename="../timeoutdialog.cpp" line="63"/>
        <source>%n second(s) remaining</source>
        <translatorcomment>%n másodperc van hátra</translatorcomment>
        <translation>
            <numerusform>%n másodperc van hátra</numerusform>
        </translation>
    </message>
</context>
</TS>
